.. testsetup:: *

   from pwnlib.util.getdents import *
   from pwnlib.util.fiddling import unhex


:mod:`pwnlib.util.getdents` --- Linux binary directory listing
==============================================================

.. automodule:: pwnlib.util.getdents
   :members:
